import * as i0 from '@angular/core';
import { Input, Directive, HostListener, Inject, Injectable, ContentChild, ContentChildren, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import { Subject } from 'rxjs';
import { tap, takeUntil } from 'rxjs/operators';

class FocusAutoDirective {
    set delay(val) {
        this.focusElement(val);
    }
    constructor(el) {
        this.el = el;
    }
    focusElement(delay) {
        setTimeout(() => this.el.nativeElement.focus(), delay || 0);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusAutoDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusAutoDirective, selector: "[fuAuto]", inputs: { delay: ["fuAuto", "delay"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusAutoDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuAuto]'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { delay: [{
                type: Input,
                args: ['fuAuto']
            }] } });

var Keys;
(function (Keys) {
    Keys["Enter"] = "Enter";
    Keys["Escape"] = "Escape";
    Keys["Tab"] = "Tab";
    Keys["ArrowDown"] = "ArrowDown";
    Keys["ArrowRight"] = "ArrowRight";
    Keys["ArrowUp"] = "ArrowUp";
    Keys["ArrowLeft"] = "ArrowLeft";
})(Keys || (Keys = {}));

class FocusControlDirective {
    set config(val) {
        this._config = val;
    }
    get config() {
        return this._config;
    }
    constructor(document) {
        this.document = document;
    }
    goTo($event) {
        if ($event.key === Keys.Tab) {
            if ($event.shiftKey && this.config.previous) {
                $event.preventDefault();
                this.focusElement(this.config.previous);
            }
            else if (!$event.shiftKey && this.config.next) {
                $event.preventDefault();
                this.focusElement(this.config.next);
            }
        }
    }
    focusElement(element) {
        if (typeof element === 'string') {
            this.document.querySelector(element)?.focus();
        }
        else {
            element.focus();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusControlDirective, deps: [{ token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusControlDirective, selector: "[fuControl]", inputs: { config: ["fuControl", "config"] }, host: { listeners: { "keydown": "goTo($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusControlDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuControl]'
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }], propDecorators: { config: [{
                type: Input,
                args: ['fuControl']
            }], goTo: [{
                type: HostListener,
                args: [`keydown`, ['$event']]
            }] } });

class FocusSelectorDirective {
    constructor(document, el) {
        this.document = document;
        this.el = el;
    }
    goTo($event) {
        if ($event.key === Keys.Tab) {
            const elements = Array.from(this.document.querySelectorAll(this.selector));
            const index = elements.findIndex(item => item === this.el.nativeElement);
            if ($event.shiftKey && index > 0) {
                $event.preventDefault();
                $event.stopPropagation();
                elements[index - 1].focus();
            }
            else if (!$event.shiftKey && index < elements.length - 1) {
                $event.preventDefault();
                $event.stopPropagation();
                elements[index + 1].focus();
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusSelectorDirective, deps: [{ token: DOCUMENT }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusSelectorDirective, selector: "[fuSelector]", inputs: { selector: ["fuSelector", "selector"] }, host: { listeners: { "keydown": "goTo($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusSelectorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuSelector]'
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i0.ElementRef }], propDecorators: { selector: [{
                type: Input,
                args: ['fuSelector']
            }], goTo: [{
                type: HostListener,
                args: [`keydown`, ['$event']]
            }] } });

class Helper {
    static stopEvent($event) {
        $event.preventDefault();
        $event.stopPropagation();
    }
}

const ControlKeys = {
    enterGroup: Keys.Enter,
    leaveGroup: Keys.Escape,
    navigation: Keys.Tab,
    navNext1: Keys.ArrowDown,
    navNext2: Keys.ArrowRight,
    navPrev1: Keys.ArrowUp,
    navPrev2: Keys.ArrowLeft,
};
const DEFAULT_CONFIG = {
    selector: ':scope > *',
    tabIndex: 0,
};
const TAB_GROUP_CONTEXT_ATTR = 'data-tabGroupContext';
const MUTATION_OBSERVER_CONFIG$1 = {
    childList: true,
    subtree: true,
};
class FocusGroupDirective {
    set config(val) {
        this._config = val;
    }
    get config() {
        return { ...DEFAULT_CONFIG, ...this._config };
    }
    constructor(document, renderer, el) {
        this.document = document;
        this.renderer = renderer;
        this.el = el;
        this.elementClickEventListeners = new WeakMap();
    }
    ngOnInit() {
        const elements = this.getFocusableChildren();
        this.setupClickEventListeners(elements);
        this.observer = new MutationObserver(() => this.setupClickEventListeners(elements));
        this.observer.observe(this.el.nativeElement, MUTATION_OBSERVER_CONFIG$1);
    }
    ngOnDestroy() {
        this.getFocusableChildren().forEach(element => this.elementClickEventListeners.has(element) && this.elementClickEventListeners.get(element)());
        this.observer.disconnect();
    }
    enterGroup($event) {
        Helper.stopEvent($event);
        const elements = this.getFocusableChildren();
        if (!this.activeElement && elements[0]) {
            this.initializeElement(elements[0]);
        }
    }
    setupClickEventListeners(elements) {
        elements.forEach(element => {
            this.elementClickEventListeners.set(element, this.renderer.listen(element, 'click', this.initializeElement.bind(this, element)));
        });
    }
    getFocusableChildren() {
        return Array.from(this.el.nativeElement.querySelectorAll(this.config.selector));
    }
    elementBlurFunction($event) {
        // setTimeout is important here, because next item is focused in next tick
        setTimeout(() => !this.someChildIsFocused() && this.leaveGroup($event.target, false));
    }
    initializeElement(element) {
        this.activeElement = element;
        if (element.hasAttribute('tabindex')) {
            this.renderer.setAttribute(element, TAB_GROUP_CONTEXT_ATTR, element.getAttribute('tabindex'));
        }
        this.renderer.setAttribute(element, 'tabindex', String(this.config.tabIndex));
        this.childKeyDownEventListener = this.renderer.listen(element, 'keydown', this.childKeyDown.bind(this));
        this.elementBlurEventListener = this.renderer.listen(element, 'blur', this.elementBlurFunction.bind(this));
        element.focus();
    }
    disposeElement(element) {
        this.activeElement = null;
        if (element.hasAttribute(TAB_GROUP_CONTEXT_ATTR)) {
            this.renderer.setAttribute(element, 'tabindex', element.getAttribute(TAB_GROUP_CONTEXT_ATTR));
        }
        else {
            this.renderer.removeAttribute(element, 'tabindex');
        }
        this.childKeyDownEventListener();
        this.elementBlurEventListener();
    }
    someChildIsFocused() {
        return this.getFocusableChildren().some(item => item === this.document.activeElement);
    }
    childKeyDown($event) {
        if ($event.key === ControlKeys.leaveGroup) {
            Helper.stopEvent($event);
            this.leaveGroup($event.target);
        }
        else if (this.isPreviousNavigationKey($event)) {
            Helper.stopEvent($event);
            this.focusPrevious($event.target);
        }
        else if (this.isNextNavigationKey($event)) {
            Helper.stopEvent($event);
            this.focusNext($event.target);
        }
    }
    isPreviousNavigationKey($event) {
        return ($event.key === ControlKeys.navigation && $event.shiftKey) ||
            $event.key === ControlKeys.navPrev1 || $event.key === ControlKeys.navPrev2;
    }
    isNextNavigationKey($event) {
        return ($event.key === ControlKeys.navigation && !$event.shiftKey) ||
            $event.key === ControlKeys.navNext1 || $event.key === ControlKeys.navNext2;
    }
    focusPrevious(current) {
        const focusableChildren = this.getFocusableChildren();
        const currentFocusedIndex = focusableChildren.findIndex(item => item === current);
        const previousFocusableIndex = currentFocusedIndex - 1 < 0 ? focusableChildren.length - 1 : currentFocusedIndex - 1;
        this.disposeElement(focusableChildren[currentFocusedIndex]);
        this.initializeElement(focusableChildren[previousFocusableIndex]);
    }
    focusNext(current) {
        const focusableChildren = this.getFocusableChildren();
        const currentFocusedIndex = focusableChildren.findIndex(item => item === current);
        const nextFocusableIndex = currentFocusedIndex + 1 >= focusableChildren.length ? 0 : currentFocusedIndex + 1;
        this.disposeElement(focusableChildren[currentFocusedIndex]);
        this.initializeElement(focusableChildren[nextFocusableIndex]);
    }
    leaveGroup(current, shouldFocusGroup = true) {
        this.disposeElement(current);
        if (shouldFocusGroup) {
            this.el.nativeElement.focus();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusGroupDirective, deps: [{ token: DOCUMENT }, { token: i0.Renderer2 }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusGroupDirective, selector: "[fuGroup]", inputs: { config: ["fuGroup", "config"] }, host: { listeners: { "keyup.Enter": "enterGroup($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusGroupDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuGroup]'
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i0.Renderer2 }, { type: i0.ElementRef }], propDecorators: { config: [{
                type: Input,
                args: ['fuGroup']
            }], enterGroup: [{
                type: HostListener,
                args: [`keyup.${ControlKeys.enterGroup}`, ['$event']]
            }] } });

const FOCUSABLE_ELEMENTS = ['a', 'button', 'input', 'textarea', 'select', 'details', '[tabindex]:not([tabindex="-1"])'];
const FOCUSABLE_ELEMENTS_SELECTOR = FOCUSABLE_ELEMENTS.join(', ');

const DELAY = 0;
const MUTATION_OBSERVER_CONFIG = {
    childList: true,
    subtree: true,
};
class FocusLockDirective {
    constructor(document, renderer, el) {
        this.document = document;
        this.renderer = renderer;
        this.el = el;
    }
    ngOnInit() {
        setTimeout(() => this.createLock(), DELAY);
        this.observer = new MutationObserver(() => this.createLock());
        this.observer.observe(this.el.nativeElement, MUTATION_OBSERVER_CONFIG);
    }
    ngOnDestroy() {
        this.disposeLock();
        this.observer.disconnect();
    }
    createLock() {
        this.disposeLock();
        const [firstChild, lastChild] = this.getChildren();
        this.firstChildKeyDownEventListener = this.renderer.listen(firstChild, 'keydown', ($event) => this.childKeyDown($event, lastChild, true));
        this.lastChildKeyDownEventListener = this.renderer.listen(lastChild, 'keydown', ($event) => this.childKeyDown($event, firstChild, false));
    }
    getChildren() {
        const children = this.el.nativeElement.querySelectorAll(FOCUSABLE_ELEMENTS_SELECTOR);
        return [children[0], children[children.length - 1]];
    }
    disposeLock() {
        this.firstChildKeyDownEventListener && this.firstChildKeyDownEventListener();
        this.lastChildKeyDownEventListener && this.lastChildKeyDownEventListener();
    }
    childKeyDown($event, targetElem, shouldShiftBePressed) {
        if ($event.key === Keys.Tab && $event.shiftKey === shouldShiftBePressed) {
            Helper.stopEvent($event);
            targetElem.focus();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusLockDirective, deps: [{ token: DOCUMENT }, { token: i0.Renderer2 }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusLockDirective, selector: "[fuLock]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusLockDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuLock]'
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i0.Renderer2 }, { type: i0.ElementRef }] });

class FocusIfDirective {
    set value(val) {
        if (this.booleanGuard(val)) {
            this.doActionByValue(val);
        }
        else {
            this.subscribeObservable(val);
        }
    }
    constructor(el) {
        this.el = el;
        this.unsubscribe$ = new Subject();
    }
    ngOnDestroy() {
        this.unsubscribe$.next();
        this.unsubscribe$.complete();
    }
    subscribeObservable(obs) {
        obs.pipe(tap(obsVal => this.doActionByValue(obsVal)), takeUntil(this.unsubscribe$)).subscribe();
    }
    doActionByValue(val) {
        setTimeout(() => val ? this.el.nativeElement.focus() : this.el.nativeElement.blur());
    }
    booleanGuard(val) {
        return typeof val === 'boolean';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusIfDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusIfDirective, selector: "[fuIf]", inputs: { value: ["fuIf", "value"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusIfDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuIf]'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { value: [{
                type: Input,
                args: ['fuIf']
            }] } });

const HISTORY_SIZE = 500;
class FocusHistoryService {
    constructor() {
        this.focusedElements = [];
    }
    getHistory() {
        return this.focusedElements;
    }
    pushElement(element) {
        this.focusedElements = [...this.focusedElements, element].slice(-HISTORY_SIZE);
    }
    popElement() {
        this.focusedElements = this.focusedElements.slice(0, -1);
    }
    clearHistory() {
        this.focusedElements = [];
    }
    getLastElement() {
        return this.focusedElements.length ? this.focusedElements[this.focusedElements.length - 1] : null;
    }
    focusPrevious() {
        this.popElement();
        this.getLastElement()?.focus();
        this.popElement(); // focus method adds element into array again, but it is already there, so newly one we need remove
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusHistoryService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusHistoryService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusHistoryService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [] });

class FocusHistoryDirective {
    constructor(el, service) {
        this.el = el;
        this.service = service;
    }
    focus() {
        this.service.pushElement(this.el.nativeElement);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusHistoryDirective, deps: [{ token: i0.ElementRef }, { token: FocusHistoryService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusHistoryDirective, selector: "[fuHistory]", host: { listeners: { "focus": "focus()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusHistoryDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuHistory]'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: FocusHistoryService }], propDecorators: { focus: [{
                type: HostListener,
                args: ['focus']
            }] } });

class FocusCaseDirective {
    constructor(el) {
        this.el = el;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusCaseDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusCaseDirective, selector: "[fuCase]", inputs: { value: ["fuCase", "value"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusCaseDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuCase]'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { value: [{
                type: Input,
                args: ['fuCase']
            }] } });

class FocusDefaultDirective {
    constructor(el) {
        this.el = el;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusDefaultDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusDefaultDirective, selector: "[fuDefault]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusDefaultDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuDefault]'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

class FocusSwitchDirective {
    set value(val) {
        if (this.observableGuard(val)) {
            this.subscribeObservable(val);
        }
        else {
            this.doActionByValue(val);
        }
    }
    constructor() {
        this.unsubscribe$ = new Subject();
    }
    ngOnDestroy() {
        this.unsubscribe$.next();
        this.unsubscribe$.complete();
    }
    doActionByValue(val) {
        setTimeout(() => {
            const caseOption = this.cases?.find(item => item.value === val);
            if (caseOption) {
                caseOption.el.nativeElement.focus();
            }
            else {
                this.defaultCase && this.defaultCase.el.nativeElement.focus();
            }
        });
    }
    subscribeObservable(obs) {
        obs.pipe(tap(obsVal => this.doActionByValue(obsVal)), takeUntil(this.unsubscribe$)).subscribe();
    }
    observableGuard(val) {
        return typeof val === 'object';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusSwitchDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusSwitchDirective, selector: "[fuSwitch]", inputs: { value: ["fuSwitch", "value"] }, queries: [{ propertyName: "defaultCase", first: true, predicate: FocusDefaultDirective, descendants: true }, { propertyName: "cases", predicate: FocusCaseDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusSwitchDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuSwitch]'
                }]
        }], ctorParameters: () => [], propDecorators: { cases: [{
                type: ContentChildren,
                args: [FocusCaseDirective]
            }], defaultCase: [{
                type: ContentChild,
                args: [FocusDefaultDirective]
            }], value: [{
                type: Input,
                args: ['fuSwitch']
            }] } });

class FocusUnleavableDirective {
    set config(val) {
        this.active = val;
    }
    constructor(el) {
        this.el = el;
        this.active = false;
    }
    onBlur() {
        this.active && this.el.nativeElement.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusUnleavableDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.12", type: FocusUnleavableDirective, selector: "[fuUnleavable]", inputs: { config: ["fuUnleavable", "config"] }, host: { listeners: { "blur": "onBlur()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: FocusUnleavableDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fuUnleavable]'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { config: [{
                type: Input,
                args: ['fuUnleavable']
            }], onBlur: [{
                type: HostListener,
                args: ['blur']
            }] } });

class NgxFocusControlModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NgxFocusControlModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.12", ngImport: i0, type: NgxFocusControlModule, declarations: [FocusControlDirective,
            FocusSelectorDirective,
            FocusGroupDirective,
            FocusAutoDirective,
            FocusLockDirective,
            FocusIfDirective,
            FocusHistoryDirective,
            FocusSwitchDirective,
            FocusCaseDirective,
            FocusDefaultDirective,
            FocusUnleavableDirective], exports: [FocusControlDirective,
            FocusSelectorDirective,
            FocusGroupDirective,
            FocusAutoDirective,
            FocusLockDirective,
            FocusIfDirective,
            FocusHistoryDirective,
            FocusSwitchDirective,
            FocusCaseDirective,
            FocusDefaultDirective,
            FocusUnleavableDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NgxFocusControlModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NgxFocusControlModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        FocusControlDirective,
                        FocusSelectorDirective,
                        FocusGroupDirective,
                        FocusAutoDirective,
                        FocusLockDirective,
                        FocusIfDirective,
                        FocusHistoryDirective,
                        FocusSwitchDirective,
                        FocusCaseDirective,
                        FocusDefaultDirective,
                        FocusUnleavableDirective,
                    ],
                    imports: [],
                    exports: [
                        FocusControlDirective,
                        FocusSelectorDirective,
                        FocusGroupDirective,
                        FocusAutoDirective,
                        FocusLockDirective,
                        FocusIfDirective,
                        FocusHistoryDirective,
                        FocusSwitchDirective,
                        FocusCaseDirective,
                        FocusDefaultDirective,
                        FocusUnleavableDirective,
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-focus-control
 */

/**
 * Generated bundle index. Do not edit.
 */

export { FocusAutoDirective, FocusCaseDirective, FocusControlDirective, FocusDefaultDirective, FocusGroupDirective, FocusHistoryDirective, FocusHistoryService, FocusIfDirective, FocusLockDirective, FocusSelectorDirective, FocusSwitchDirective, FocusUnleavableDirective, NgxFocusControlModule };
//# sourceMappingURL=ngx-focus-control.mjs.map
